﻿using XF.Domain.Cache;
using XF.Domain.Dependency;

namespace Sharing.Api
{
    /// <summary>
    /// 
    /// </summary>
    public class ProvinceService: IProvinceService, ISelfDependency
    {
        private const string OrderNoPrefix = "ProvinceOrderNo:";

        private readonly ITypedCache<CacheOrderNO> _cacheOrderNo;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="cacheOrderNo"></param>
        public ProvinceService(ITypedCache<CacheOrderNO> cacheOrderNo)
        {
            _cacheOrderNo = cacheOrderNo;
        }

        public string GenerateNewOrderNo(DateTime today)
        {
            var cacheKey = $"{OrderNoPrefix}{today:yyyyMMdd}";

            var cacheOrderNo = _cacheOrderNo.Get(cacheKey);
            if (cacheOrderNo == null)
            {
                cacheOrderNo = new CacheOrderNO { TotalCount = 0 };
            }

            cacheOrderNo!.TotalCount += 1;
            var no = GenerateOrderNo(today, cacheOrderNo.TotalCount);
            _cacheOrderNo.Set(cacheKey, cacheOrderNo);
            return no;
        }

        private string GenerateOrderNo(DateTime today, int count)
        {
            return $"{today:yyMMdd}{count.ToString("00000")}";
        }

        /// <summary>
        /// 缓存类
        /// </summary>
        public class CacheOrderNO
        {
            public int TotalCount { get; set; }
        }
    }
}
